;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: `@INSTANCE_NAME`.asm
;;   Version: 1.2, Updated on 2005/10/05
;;  `@PSOC_VERSION`
;;
;;  DESCRIPTION: OneShot8 User Module software implementation file
;;               for the 21/22/24/25/26/27/29xxx PSoC family of devices.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API functions
;;        returns. For Large Memory Model devices it is also the caller's 
;;        responsibility to perserve any value in the CUR_PP, IDX_PP, MVR_PP and 
;;        MVW_PP registers. Even though some of these registers may not be modified
;;        now, there is no guarantee that will remain the case in future releases.
;;-----------------------------------------------------------------------------
;;      Copyright (c) Ilya Mamontov 2004.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "`@INSTANCE_NAME`.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export   `@INSTANCE_NAME`_Start
export  _`@INSTANCE_NAME`_Start
export   `@INSTANCE_NAME`_Stop
export  _`@INSTANCE_NAME`_Stop

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------
bfCONTROL_REG_START_BIT:   equ   1        ; Control register start bit


AREA UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: `@INSTANCE_NAME`_Start
;
;  DESCRIPTION:
;     Starts the OneShot user module.  The OneShot will begin computing the psuedo
;     random number sequence on subsequent clocks.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: None
;
;  RETURNS:   None
;
;
;
 `@INSTANCE_NAME`_Start:
_`@INSTANCE_NAME`_Start:
   RAM_PROLOGUE RAM_USE_CLASS_1
   or    REG[`@OneShot8_CONTROL_0`], bfCONTROL_REG_START_BIT
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: `@INSTANCE_NAME`_Stop
;
;  DESCRIPTION:
;     Disables OneShot operation.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: None
;
;  RETURNS:   None
;
;
 `@INSTANCE_NAME`_Stop:
_`@INSTANCE_NAME`_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   and   REG[`@OneShot8_CONTROL_0`], ~bfCONTROL_REG_START_BIT
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

; End of File `@INSTANCE_NAME`.asm
